==> 1.0.3.tar.gz: lib/week_labels.dart <==
import 'package:flutter/material.dart';
import 'package:heatmap_calendar_shamsi/default_container.dart';

class WeekLabels extends StatelessWidget {
  final List<String> weekDaysLabels;
  final double squareSize;
  final Color labelTextColor;

  const WeekLabels(
      {Key key,
      @required this.weekDaysLabels,
      @required this.squareSize,
      @required this.labelTextColor})
      : assert(weekDaysLabels != null),
        assert(weekDaysLabels.length == 7),
        assert(squareSize != null),
        assert(squareSize > 0),
        assert(labelTextColor != null),
        super(key: key);

  @override
  Widget build(BuildContext context) {
    return Column(
      children: <Widget>[
        DefaultContainer(
          text: "",
          size: squareSize,
          textColor: labelTextColor,
          margin: 0,
        ),
        DefaultContainer(
          text: weekDaysLabels[0],
          size: squareSize,
          textColor: labelTextColor,
        ),
        DefaultContainer(
          text: weekDaysLabels[1],
          size: squareSize,
          textColor: labelTextColor,
        ),
        DefaultContainer(
          text: weekDaysLabels[2],
          size: squareSize,
          textColor: labelTextColor,
        ),
        DefaultContainer(
          text: weekDaysLabels[3],
          size: squareSize,
          textColor: labelTextColor,
        ),
        DefaultContainer(
          text: weekDaysLabels[4],
          size: squareSize,
          textColor: labelTextColor,
        ),
        DefaultContainer(
          text: weekDaysLabels[5],
          size: squareSize,
          textColor: labelTextColor,
        ),
        DefaultContainer(
          text: weekDaysLabels[6],
          size: squareSize,
          textColor: labelTextColor,
        ),
      ],
    );
  }
}

==> 1.0.6.tar.gz: lib/week_labels.dart <==
import 'package:flutter/material.dart';
import 'package:heatmap_calendar_shamsi/default_container.dart';

const shamsiWeekLables = [
  'ش',
  'ی',
  'د',
  'س',
  'چ',
  'پ',
  'چ',
];

class WeekLabels extends StatelessWidget {
  final double squareSize;
  final Color labelTextColor;

  const WeekLabels(
      {Key key, @required this.squareSize, @required this.labelTextColor})
      : assert(squareSize != null),
        assert(squareSize > 0),
        assert(labelTextColor != null),
        super(key: key);

  @override
  Widget build(BuildContext context) {
    return Column(
      children: <Widget>[
        DefaultContainer(
          text: "",
          size: squareSize,
          textColor: labelTextColor,
          margin: 0,
        ),
        DefaultContainer(
          text: shamsiWeekLables[0],
          size: squareSize,
          textColor: labelTextColor,
        ),
        DefaultContainer(
          text: shamsiWeekLables[1],
          size: squareSize,
          textColor: labelTextColor,
        ),
        DefaultContainer(
          text: shamsiWeekLables[2],
          size: squareSize,
          textColor: labelTextColor,
        ),
        DefaultContainer(
          text: shamsiWeekLables[3],
          size: squareSize,
          textColor: labelTextColor,
        ),
        DefaultContainer(
          text: shamsiWeekLables[4],
          size: squareSize,
          textColor: labelTextColor,
        ),
        DefaultContainer(
          text: shamsiWeekLables[5],
          size: squareSize,
          textColor: labelTextColor,
        ),
        DefaultContainer(
          text: shamsiWeekLables[6],
          size: squareSize,
          textColor: labelTextColor,
        ),
      ],
    );
  }
}
